@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-sidebar-embed.c,v 1.8.2.2 2005/04/19 10:03:41 chpe Exp $
+ * $Id: ephy-sidebar-embed.c,v 1.13 2005/10/10 19:02:26 chpe Exp $
  */
 
 #include "config.h"
@@ -48,6 +48,8 @@
 
 #include <string.h>
 
+#define EPIPHANY_GETTEXT_DOMAIN	"epiphany"
+
 #define EPHY_SIDEBAR_EMBED_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SIDEBAR_EMBED, EphySidebarEmbedPrivate))
 
 struct _EphySidebarEmbedPrivate
@@ -148,17 +150,28 @@ popup_menu_at_coords (GtkMenu *menu,
 }
 
 static void
-hide_embed_popup_cb (GtkMenu *menu,
-		     GtkUIManager *manager)
+embed_popup_deactivate_cb (GtkMenu *menu,
+			   EphyWindow *window)
 {
+	GtkUIManager *manager;
 	GtkAction *action;
 
+	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
+
+	g_signal_handlers_disconnect_by_func
+		(menu, G_CALLBACK (embed_popup_deactivate_cb), window);
+
 	action = gtk_ui_manager_get_action (manager, "/EphyInputPopup/EditCopyIP");
-	g_object_set (action, "sensitive", TRUE, "visible", TRUE, NULL);
+	gtk_action_set_sensitive (action, TRUE);
+	gtk_action_set_visible (action, TRUE);
 	action = gtk_ui_manager_get_action (manager, "/EphyInputPopup/EditCutIP");
-	g_object_set (action, "sensitive", TRUE, "visible", TRUE, NULL);
+	gtk_action_set_sensitive (action, TRUE);
+	gtk_action_set_visible (action, TRUE);
 	action = gtk_ui_manager_get_action (manager, "/EphyInputPopup/EditPasteIP");
-	g_object_set (action, "sensitive", TRUE, "visible", TRUE, NULL);
+	gtk_action_set_sensitive (action, TRUE);
+	gtk_action_set_visible (action, TRUE);
+
+	_ephy_window_unset_context_event (window);
 }
 
 static void
@@ -223,32 +236,33 @@ show_context_menu (EphySidebarEmbed *sbembed,
 
 	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
 	action = gtk_ui_manager_get_action (manager, "/EphySidebarDocumentPopup/SaveBackgroundAsDP");
-	g_object_set (action, "sensitive", has_background,
-			      "visible", has_background, NULL);
+	gtk_action_set_sensitive (action, has_background);
+	gtk_action_set_visible (action, has_background);
 	action = gtk_ui_manager_get_action (manager, "/EphyLinkPopup/OpenLinkInNewWindowLP");
-	g_object_set (action, "sensitive", can_open_in_new, NULL);
+	gtk_action_set_sensitive (action, can_open_in_new);
 	action = gtk_ui_manager_get_action (manager, "/EphyLinkPopup/OpenLinkInNewTabLP");
-	g_object_set (action, "sensitive", can_open_in_new, NULL);
+	gtk_action_set_sensitive (action, can_open_in_new);
 
 	can_copy = ephy_command_manager_can_do_command (EPHY_COMMAND_MANAGER (embed), "cmd_copy");
 	can_cut = ephy_command_manager_can_do_command (EPHY_COMMAND_MANAGER (embed), "cmd_cut");
 	can_paste = ephy_command_manager_can_do_command (EPHY_COMMAND_MANAGER (embed), "cmd_paste");
 	action = gtk_ui_manager_get_action (manager, "/EphyInputPopup/EditCopyIP");
-	g_object_set (action, "sensitive", can_copy, "visible", !hide_edit_actions || can_copy, NULL);
+	gtk_action_set_sensitive (action, can_copy);
+	gtk_action_set_visible (action, !hide_edit_actions || can_copy);
 	action = gtk_ui_manager_get_action (manager, "/EphyInputPopup/EditCutIP");
-	g_object_set (action, "sensitive", can_cut, "visible", !hide_edit_actions || can_cut, NULL);
+	gtk_action_set_sensitive (action, can_cut);
+	gtk_action_set_visible (action, !hide_edit_actions || can_cut);
 	action = gtk_ui_manager_get_action (manager, "/EphyInputPopup/EditPasteIP");
-	g_object_set (action, "sensitive", can_paste, "visible", !hide_edit_actions || can_paste, NULL);
+	gtk_action_set_sensitive (action, can_paste);
+	gtk_action_set_visible (action, !hide_edit_actions || can_paste);
 
-	g_object_set_data_full (G_OBJECT (window), "context_event",
-				g_object_ref (event),
-				(GDestroyNotify)g_object_unref);
+	_ephy_window_set_context_event (window, event);
 
 	widget = gtk_ui_manager_get_widget (manager, popup);
 	g_return_if_fail (widget != NULL);
 
-	g_signal_connect (widget, "hide",
-			  G_CALLBACK (hide_embed_popup_cb), manager);
+	g_signal_connect (widget, "deactivate",
+			  G_CALLBACK (embed_popup_deactivate_cb), window);
 
 	button = ephy_embed_event_get_button (event);
 	if (button == 0)
@@ -417,7 +431,7 @@ ephy_sidebar_embed_create_embed (EphySidebarEmbed *sbembed)
 
 #define EPHY_STOCK_DOWNLOAD	"ephy-download"
 
-static GtkActionEntry action_entries [] =
+static const GtkActionEntry action_entries [] =
 {
 	{ "SidebarSaveAs", GTK_STOCK_SAVE_AS, N_("Save _As..."), NULL,
 	  N_("Save the current page"),
@@ -452,7 +466,7 @@ ephy_sidebar_embed_set_window (EphySidebarEmbed *sbembed,
 
 	action_group = sbembed->priv->action_group =
 		gtk_action_group_new ("SidebarContextMenuActions");
-	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
+	gtk_action_group_set_translation_domain (action_group, EPIPHANY_GETTEXT_DOMAIN);
 	gtk_action_group_add_actions (action_group, action_entries,
 				      G_N_ELEMENTS (action_entries), sbembed);
 
